/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.impl;

import java.util.Date;
import it.tidalwave.metadata.spi.MetadataItemEnhancer;
import it.tidalwave.metadata.mock.CompositeMockItem;
import it.tidalwave.metadata.mock.MockItem1;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class MetadataItemAspectTest
  {
    private CompositeMockItem enhancedItem;
    private MockItem1 item;
        
    @Before
    public void setUp() 
      {
        enhancedItem = MetadataItemEnhancer.createEnhancedItem(new CompositeMockItem());
        item = new MockItem1();
      }

    @After
    public void tearDown() 
      {
        enhancedItem = null;
        item = null;
      }
    
    @Test
    public void testIsAvailableGetsTrue()
      {
        assertNull(enhancedItem.getName());
        assertFalse(enhancedItem.isNameAvailable());
        assertFalse(enhancedItem.isAvailable());
        enhancedItem.setName("the name");
        assertEquals("the name", enhancedItem.getName());
        assertTrue(enhancedItem.isNameAvailable());
        assertTrue(enhancedItem.isAvailable());
        
        enhancedItem.setName(null);
        assertNull(enhancedItem.getName());
        assertTrue(enhancedItem.isNameAvailable());
        assertTrue(enhancedItem.isAvailable());
      }

    @Test
    public void testIsPropertyGetsNull()
      {
        enhancedItem.setName("the name");
        assertEquals("the name", enhancedItem.getName());
        assertTrue(enhancedItem.isNameAvailable());
        assertTrue(enhancedItem.isAvailable());
        
        enhancedItem.setNameAvailable(false);
        assertFalse(enhancedItem.isNameAvailable());
        assertFalse(enhancedItem.isAvailable());
        assertNull(enhancedItem.getName());
        
        enhancedItem.setNameAvailable(true);
        assertTrue(enhancedItem.isNameAvailable());
        assertTrue(enhancedItem.isAvailable());
        assertNull(enhancedItem.getName());
      }
    
    @Test
    public void testAvailablePropertiesFixedByEnhancer()
      {
        item.setName("the name");
        assertEquals("the name", item.getName());
        assertFalse(item.isNameAvailable());
        assertFalse(item.isAvailable());
        MetadataItemEnhancer.createEnhancedItem(item);
        assertEquals("the name", item.getName());
        assertTrue(item.isNameAvailable());
        assertTrue(item.isAvailable());
      }
    
//    @Test
//    public void testLatestModificationTime()
//      throws Exception
//      {
//        assertNull(((MetadataItem)enhancedItem).getLatestModificationTime());
//        Thread.sleep(1000);
//        Date now = new Date();
//        enhancedItem.setName("the name 1");
//        Date lmd = ((MetadataItem)enhancedItem).getLatestModificationTime();
//        assertTrue(lmd.getTime() - now.getTime() < 50);
//        Thread.sleep(1000);
//        now = new Date();
//        enhancedItem.setName("the name 2");
//        lmd = ((MetadataItem)enhancedItem).getLatestModificationTime();
//        assertTrue(lmd.getTime() - now.getTime() < 50);
//      }
    
//    @Test
//    public void testLatestModificationTimeFromInnerBeans()
//      throws Exception
//      {
//        assertNull(((MetadataItem)enhancedItem).getLatestModificationTime());
//        Thread.sleep(1000);
//        Date now = new Date();
//        enhancedItem.getItem1().setName("the name 1");
//        Date lmd = ((MetadataItem)enhancedItem).getLatestModificationTime();
//        assertTrue(lmd.getTime() - now.getTime() < 50);
//        Thread.sleep(1000);
//        now = new Date();
//        enhancedItem.getItem2().setName("the name 2");
//        lmd = ((MetadataItem)enhancedItem).getLatestModificationTime();
//        assertTrue(lmd.getTime() - now.getTime() < 50);
//      }
    
//    @Test
//    public void testCheckForInvalidBean()
//      {
//        class MockItemWithoutIsAvailable
//          {
//            private String name;
//            private boolean nameAvailable;
//
//            public void setName (final String name)
//              {
//                this.name = name;    
//              }
//
//            public String getName()
//              {
//                return name;    
//              }
//
//            public void setNameAvailable (final boolean nameAvailable)
//              {
//                this.nameAvailable = nameAvailable;    
//              }
//
//            public boolean isNameAvailable()
//              {
//                return nameAvailable;    
//              }
//          }
//        
//        try
//          {
//            MetadataItemEnhancer.createEnhancedItem(new MockItemWithoutIsAvailable());
//            fail("IllegalArgumentException excpected");
//          }
//        catch (IllegalArgumentException e)
//          {
//            // ok
//          }
//      }
  }