/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.impl;

import it.tidalwave.metadata.*;
import org.junit.Test;
import it.tidalwave.metadata.impl.MetadataItemFormatImpl;
import it.tidalwave.metadata.mock.MockItem1;
import it.tidalwave.metadata.mock.MockItem2;
import org.junit.After;
import org.junit.Before;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class MetadataItemFormatTest 
  {
    private static final Class<?> UNMANAGED_CLASS = MockItem1.class;
    private static final Class<?> MANAGED_CLASS = MockItem2.class;
    private MetadataItemFormat format;
    
    @Before
    public void setupFixture()
      {
        format = MetadataItemFormat.Locator.findMetadataItemFormat();
      }
    
    @After
    public void teardownFixture()
      {
        format = null;
      }
    
    @Test
    public void testLocator() 
      {
        assertNotNull(format);
        assertTrue(format instanceof MetadataItemFormatImpl);
      }
    
    @Test 
    public void testGetItemDisplayNameUnmanaged()
      {
        assertEquals("MockItem1", format.getItemDisplayName(UNMANAGED_CLASS));
      }
    
    @Test
    public void testGetPropertyDisplayNameUnmanaged()
      {
        assertEquals("name", format.getPropertyDisplayName(UNMANAGED_CLASS, "name"));    
        assertEquals("value", format.getPropertyDisplayName(UNMANAGED_CLASS, "value"));    
      }
    
    @Test
    public void testFormatUnmanaged()
      {
        assertEquals("the name", format.format(UNMANAGED_CLASS, "name", "the name"));
        assertEquals("34", format.format(UNMANAGED_CLASS, "value", 34));
      }
    
    @Test 
    public void testGetItemDisplayNameManaged()
      {
        assertEquals("Mock Item 2", format.getItemDisplayName(MANAGED_CLASS));
      }
    
    @Test
    public void testGetPropertyDisplayNameManaged()
      {
        assertEquals("NAME", format.getPropertyDisplayName(MANAGED_CLASS, "name"));    
        assertEquals("VALUE", format.getPropertyDisplayName(MANAGED_CLASS, "value"));    
      }
    
    public void testFormatManaged()
      {
        assertEquals("the name EV", format.format(MANAGED_CLASS, "name", "the name"));
        assertEquals("34 mm", format.format(MANAGED_CLASS, "value", 34));
      }
  }
