/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.impl;

import it.tidalwave.metadata.*;
import java.beans.PropertyChangeEvent;
import java.util.Date;
import it.tidalwave.metadata.mock.MockItem1;
import it.tidalwave.metadata.spi.MetadataItemEnhancer;
import java.beans.PropertyChangeListener;
import org.junit.Test;
import static org.junit.Assert.*;

class XXXMetadataItemHolder extends MetadataItemHolder<MockItem1>
  {
    public XXXMetadataItemHolder(MockItem1 bean, String sourceName, String origin, Date latestModificationTime)
      {
        super(bean, sourceName, origin, latestModificationTime);
      }

    public XXXMetadataItemHolder(MockItem1 bean) 
      {
        super(bean);
      }
    
    @Override
    public boolean isAvailable() 
      {
        return true;
      }
  }

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class MetadataItemHolderTest 
  {
    @Test
    public void test1() 
      {
        final MockItem1 bean = MetadataItemEnhancer.createEnhancedItem(new MockItem1());
        final XXXMetadataItemHolder holder = new XXXMetadataItemHolder(bean);
        assertSame(bean, holder.get());
        assertNull(holder.getLatestModificationTime());
        assertNull(holder.getSourceName());
        assertNull(holder.getOrigin());
        assertEquals(holder.hashCode(), bean.hashCode());
        assertEquals(String.format("XXXMetadataItemHolder[null, null, %s]", bean.toString()), holder.toString());
      }

    @Test
    public void test2() 
      {
        final MockItem1 bean = MetadataItemEnhancer.createEnhancedItem(new MockItem1());
        final Date date = new Date();
        final XXXMetadataItemHolder holder = new XXXMetadataItemHolder(bean, "source", "origin", date);
        assertSame(bean, holder.get());
        assertEquals(date, holder.getLatestModificationTime());
        assertEquals("source", holder.getSourceName());
        assertEquals("origin", holder.getOrigin());
        assertEquals(holder.hashCode(), bean.hashCode());
        assertEquals(String.format("XXXMetadataItemHolder[origin, source, %s]", bean.toString()), holder.toString());
      }
    
    @Test
    public void testHolderWithNullBean()
      {
        try
          {
            new XXXMetadataItemHolder(null);
            fail("NullPointerException expected");
//            fail("IllegalArgumentException expected");
          }
        catch (NullPointerException e)
//        catch (IllegalArgumentException e)
          {
            // ok
          }
      }
    
    @Test
    public void testPropertyChangeListeners()
      {
        final PropertyChangeListener listener = new PropertyChangeListener() 
          {
            public void propertyChange(PropertyChangeEvent evt) 
              {
              }
          };
          
        final MockItem1 bean = MetadataItemEnhancer.createEnhancedItem(new MockItem1());
        final XXXMetadataItemHolder holder = new XXXMetadataItemHolder(bean);
        assertEquals(0, holder.getPropertyChangeListeners().length);
        
        holder.addPropertyChangeListener(listener);
        assertEquals(new PropertyChangeListener[] {listener}, holder.getPropertyChangeListeners());
        
        holder.removePropertyChangeListener(listener);
        assertEquals(0, holder.getPropertyChangeListeners().length);
     }
  }