/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.impl;

import it.tidalwave.metadata.*;
import java.util.Date;
import it.tidalwave.metadata.impl.TimestampProviderImpl;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class TimestampProviderTest 
  {
    private TimestampProvider timestampProvider;
            
    @Before
    public void setupFixture()
      {
        timestampProvider = new TimestampProviderImpl();
      }
    
    @After
    public void tearDownFixture()
      {
        timestampProvider = null;
      }
    
    @Test
    public void testSample() 
      throws Exception
      {
        final Date timestamp1 = timestampProvider.sample();
        assertNotNull(timestamp1);
        
        for (int i = 0; i < 10; i++)
          {
            Thread.sleep(100);
            assertEquals(timestamp1, timestampProvider.getSampledTimestamp());
          }
            
        final Date timestamp2 = timestampProvider.sample();
        assertFalse(timestamp1.equals(timestamp2));
        assertNotNull(timestamp2);
        
        for (int i = 0; i < 10; i++)
          {
            Thread.sleep(100);
            assertEquals(timestamp2, timestampProvider.getSampledTimestamp());
          }
      }
    
    @Test
    public void testGetSampledTimestampWithNoSample()
      {
        assertNotNull(timestampProvider.getSampledTimestamp());
      }
    
    @Test
    public void testServiceInstalled()
      {
        assertTrue(TimestampProvider.Locator.findTimestampProvider() instanceof TimestampProviderImpl);
      }
  }